@@ -38,7 +38,7 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.13.0.2'; # TRIAL VERSION
+our $VERSION = '1.13.0.3'; # TRIAL VERSION
 
 use Rex::Commands;
 use Rex::Value;
@@ -134,23 +134,9 @@ sub cmdb {
 
   return if !cmdb_active();
 
-  $server = $CMDB_PROVIDER->__get_hostname_for($server);
+  $CMDB_PROVIDER->__warm_up_cache_for($server);
 
-  my $value;
-  my $cache     = Rex::get_cache();
-  my $cache_key = "cmdb/$CMDB_PROVIDER/$server";
-
-  if ( $cache->valid($cache_key) ) {
-    $value = $cache->get($cache_key);
-  }
-  else {
-    $value = $CMDB_PROVIDER->get( undef, $server ) || undef;
-    $cache->set( $cache_key, $value );
-  }
-
-  if ($item) {
-    $value = $value->{$item};
-  }
+  my $value = $CMDB_PROVIDER->get( $item, $server );
 
   if ( defined $value ) {
     return Rex::Value->new( value => $value );
