@@ -10,7 +10,7 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.13.0.2'; # TRIAL VERSION
+our $VERSION = '1.13.0.3'; # TRIAL VERSION
 
 use base qw(Rex::CMDB::Base);
 
@@ -72,37 +72,52 @@ sub new {
 sub get {
   my ( $self, $item, $server ) = @_;
 
-  my @files = $self->_get_cmdb_files( $item, $server );
+  $server = $self->__get_hostname_for($server);
 
-  my $all = {};
-  Rex::Logger::debug( Dumper( \@files ) );
+  my $result = {};
 
-  # configuration variables
-  my $config_values = Rex::Config->get_all;
-  my %template_vars;
-  for my $key ( keys %{$config_values} ) {
-    if ( !exists $template_vars{$key} ) {
-      $template_vars{$key} = $config_values->{$key};
-    }
+  if ( $self->__cache->valid( $self->__cache_key() ) ) {
+    $result = $self->__cache->get( $self->__cache_key() );
   }
-  $template_vars{environment} = Rex::Commands::environment();
+  else {
 
-  for my $file (@files) {
-    Rex::Logger::debug("CMDB - Opening $file");
-    if ( -f $file ) {
+    my @files = $self->_get_cmdb_files( $item, $server );
 
-      my $content = eval { local ( @ARGV, $/ ) = ($file); <>; };
-      my $t       = Rex::Config->get_template_function();
-      $content .= "\n"; # for safety
-      $content = $t->( $content, \%template_vars );
+    Rex::Logger::debug( Dumper( \@files ) );
 
-      my $ref = YAML::Load($content);
+    # configuration variables
+    my $config_values = Rex::Config->get_all;
+    my %template_vars;
+    for my $key ( keys %{$config_values} ) {
+      if ( !exists $template_vars{$key} ) {
+        $template_vars{$key} = $config_values->{$key};
+      }
+    }
+    $template_vars{environment} = Rex::Commands::environment();
 
-      $all = $self->{merger}->merge( $all, $ref );
+    for my $file (@files) {
+      Rex::Logger::debug("CMDB - Opening $file");
+      if ( -f $file ) {
+
+        my $content = eval { local ( @ARGV, $/ ) = ($file); <>; };
+        my $t       = Rex::Config->get_template_function();
+        $content .= "\n"; # for safety
+        $content = $t->( $content, \%template_vars );
+
+        my $ref = YAML::Load($content);
+
+        $result = $self->{merger}->merge( $result, $ref );
+      }
     }
   }
 
-  return $all;
+  if ( defined $item ) {
+    return $result->{$item};
+  }
+  else {
+    return $result;
+  }
+
 }
 
 sub _get_cmdb_files {
