@@ -10,7 +10,7 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.13.0.2'; # TRIAL VERSION
+our $VERSION = '1.13.0.3'; # TRIAL VERSION
 
 use Rex::Logger;
 
@@ -18,7 +18,7 @@ use attributes;
 use Rex::Group::Entry::Server;
 
 use vars qw(%groups);
-use List::MoreUtils 0.416 qw(uniq);
+use List::Util 1.45 qw(uniq);
 use Data::Dumper;
 
 sub new {
