@@ -10,8 +10,9 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.13.0.2'; # TRIAL VERSION
+our $VERSION = '1.13.0.3'; # TRIAL VERSION
 
+use English qw(-no_match_vars);
 use Rex;
 use Rex::Commands::Run;
 use Rex::Helper::Run;
@@ -335,7 +336,11 @@ sub get_operating_system_version {
     }
   }
   elsif ( $op eq 'Windows' ) {
-    return i_run 'ver';
+    my $version = i_run 'ver', fail_ok => 1;
+
+    if ( $CHILD_ERROR == 0 ) {
+      return $version;
+    }
   }
 
   return [ i_run("uname -r") ]->[0];
